rustc_llvm::LLVMMoveToNextSectionUnstable
[-] [+]
[src]
pub unsafe extern fn LLVMMoveToNextSection(SI: SectionIteratorRef)
Moves the section iterator to point to the next section.
pub unsafe extern fn LLVMMoveToNextSection(SI: SectionIteratorRef)
Moves the section iterator to point to the next section.
Prefix searches with a type followed by a colon (e.g.
fn:) to restrict the search to a given type.
Accepted types are: fn, mod,
struct, enum,
trait, typedef (or
tdef).